@@ -564,9 +564,9 @@ def get_parser():
         '--ignore-ytdl-errors',
         default=False,
         action='store_true',
-        help='If this option is set, errors that occur when downloading with the help of Youtube-dl are ignored. '
-        + 'Thus, no further attempt will be made to download the file using youtube-dl. '
-        + 'By default, youtube-dl errors are critical, so the download of the corresponding file '
+        help='If this option is set, errors that occur when downloading with the help of yt-dlp are ignored. '
+        + 'Thus, no further attempt will be made to download the file using yt-dlp. '
+        + 'By default, yt-dlp errors are critical, so the download of the corresponding file '
         + 'will be aborted and when you run moodle-dl again, the download will be repeated.',
     )
 
