@@ -192,7 +192,10 @@ class ForumsHandler:
                 'sortdirection': 'ASC',
             }
 
-            posts_result = self.request_helper.post_REST('mod_forum_get_forum_discussion_posts', data)
+            if self.version >= 2019052000:
+                posts_result = self.request_helper.post_REST('mod_forum_get_discussion_posts', data)
+            else:
+                posts_result = self.request_helper.post_REST('mod_forum_get_forum_discussion_posts', data)
 
             posts = posts_result.get('posts', [])
 
@@ -200,16 +203,23 @@ class ForumsHandler:
                 post_message = post.get('message', '')
                 if post_message is None:
                     post_message = ''
-                post_modified = post.get('modified', 0)
 
                 post_id = post.get('id', 0)
-                post_parent = post.get('parent', 0)
-                post_userfullname = post.get('userfullname', '')
+
+                if self.version >= 2019052000:
+                    post_parent = post.get('parentid', 0)
+                    post_userfullname = post.get('author', {}).get('fullname', None)
+                    post_modified = post.get('timecreated', 0)
+                else:
+                    post_parent = post.get('parent', 0)
+                    post_userfullname = post.get('userfullname', '')
+                    post_modified = post.get('modified', 0)
+
                 if post_userfullname is None:
                     post_userfullname = "Unknown"
 
                 post_filename = PathTools.to_valid_name('[' + str(post_id) + '] ' + post_userfullname)
-                if post_parent != 0:
+                if post_parent is not None and post_parent != 0:
                     post_filename = PathTools.to_valid_name(post_filename + ' response to [' + str(post_parent) + ']')
 
                 post_path = PathTools.to_valid_name(
